pub trait SameTypes { }Expand description
Helper trait for assert_same_types to tell if two types are exactly the same.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait SameTypes { }Helper trait for assert_same_types to tell if two types are exactly the same.
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".